# midi2mqtt
Listen to MIDI signals and send them to a mqtt broker.

## Installation

It can be installed by pip from the git repo location:

    $ pip install git+https://github.com/pintman/midi2mqtt

## TODO
- test it
- publish to pypi
